@@ -1,8 +1,8 @@
 import unittest
 
-from unittest import mock
-
 from modi.module.input_module.dial import Dial
+from modi.util.msgutil import parse_message
+from modi.util.misc import MockConn
 
 
 class TestDial(unittest.TestCase):
@@ -10,9 +10,9 @@ class TestDial(unittest.TestCase):
 
     def setUp(self):
         """Set up test fixtures, if any."""
-        mock_args = (-1, -1, None)
+        self.conn = MockConn()
+        mock_args = (-1, -1, self.conn)
         self.dial = Dial(*mock_args)
-        self.dial._get_property = mock.Mock()
 
     def tearDown(self):
         """Tear down test fixtures, if any."""
@@ -20,15 +20,20 @@ class TestDial(unittest.TestCase):
 
     def test_get_degree(self):
         """Test get_degree method."""
-        self.dial.get_degree()
-        self.dial._get_property.assert_called_once_with(
-            self.dial.PropertyType.DEGREE)
+        _ = self.dial.degree
+        self.assertEqual(
+            self.conn.send_list[0],
+            parse_message(0x03, 0, -1,
+                          (Dial.DEGREE, None, 95, None))
+        )
 
     def test_get_turnspeed(self):
         """Test get_turnspeed method."""
-        self.dial.get_turnspeed()
-        self.dial._get_property.assert_called_once_with(
-            self.dial.PropertyType.TURNSPEED
+        _ = self.dial.turnspeed
+        self.assertEqual(
+            self.conn.send_list[0],
+            parse_message(0x03, 0, -1,
+                          (Dial.TURNSPEED, None, 95, None))
         )
 
 
