@@ -1,8 +1,8 @@
 import unittest
 
-from unittest import mock
-
 from modi.module.input_module.ir import Ir
+from modi.util.msgutil import parse_message
+from modi.util.misc import MockConn
 
 
 class TestIr(unittest.TestCase):
@@ -10,9 +10,9 @@ class TestIr(unittest.TestCase):
 
     def setUp(self):
         """Set up test fixtures, if any."""
-        mock_args = (-1, -1, None)
+        self.conn = MockConn()
+        mock_args = (-1, -1, self.conn)
         self.ir = Ir(*mock_args)
-        self.ir._get_property = mock.Mock()
 
     def tearDown(self):
         """Tear down test fixtures, if any."""
@@ -20,9 +20,12 @@ class TestIr(unittest.TestCase):
 
     def test_get_proximity(self):
         """Test get_proximity method."""
-        self.ir.get_proximity()
-        self.ir._get_property.assert_called_once_with(
-            self.ir.PropertyType.PROXIMITY)
+        _ = self.ir.proximity
+        self.assertEqual(
+            self.conn.send_list[0],
+            parse_message(0x03, 0, -1,
+                          (Ir.PROXIMITY, None, 95, None))
+        )
 
 
 if __name__ == "__main__":
