@@ -1,8 +1,8 @@
 import unittest
 
-from unittest import mock
-
 from modi.module.input_module.ultrasonic import Ultrasonic
+from modi.util.msgutil import parse_message
+from modi.util.misc import MockConn
 
 
 class TestUltrasonic(unittest.TestCase):
@@ -10,9 +10,9 @@ class TestUltrasonic(unittest.TestCase):
 
     def setUp(self):
         """Set up test fixtures, if any."""
-        mock_args = (-1, -1, None)
+        self.conn = MockConn()
+        mock_args = (-1, -1, self.conn)
         self.ultrasonic = Ultrasonic(*mock_args)
-        self.ultrasonic._get_property = mock.Mock()
 
     def tearDown(self):
         """Tear down test fixtures, if any."""
@@ -20,8 +20,13 @@ class TestUltrasonic(unittest.TestCase):
 
     def test_get_distance(self):
         """Test get_distance method."""
-        self.ultrasonic.get_distance()
-
-        self.ultrasonic._get_property.assert_called_once_with(
-            self.ultrasonic.PropertyType.DISTANCE
+        _ = self.ultrasonic.distance
+        self.assertEqual(
+            self.conn.send_list[0],
+            parse_message(0x03, 0, -1,
+                          (Ultrasonic.DISTANCE, None, 95, None))
         )
+
+
+if __name__ == '__main__':
+    unittest.main()
