@@ -1,6 +1,6 @@
 import unittest
-# from unittest import mock
 
+from modi.util.misc import MockConn
 from modi.task.exe_task import ExeTask
 
 
@@ -9,7 +9,12 @@ class TestExeTask(unittest.TestCase):
 
     def setUp(self):
         """Set up test fixtures, if any."""
-        self.mock_kwargs = {"ser_recv_q": None, "ser_send_q": None}
+        self.topology_data = dict()
+        self.conn = MockConn()
+        self.mock_kwargs = {"topology_data": self.topology_data,
+                            "modules": [],
+                            "conn_task": self.conn,
+                            }
         self.exe_task = ExeTask(**self.mock_kwargs)
 
     def tearDown(self):
